@@ -66,15 +66,15 @@ else:
     console("未检测到Winico！")
     console("准备开始安装...")
     if is64():
-        install("https://tkdev-docs.netlify.app/_files/Winico64.zip", tkdev_winico_path)
+        install("https://tkdev-docs-old.netlify.app/_files/Winico64.zip", tkdev_winico_path)
     else:
-        install("https://tkdev-docs.netlify.app/_files/Winico32.zip", tkdev_winico_path)
+        install("https://tkdev-docs-old.netlify.app/_files/Winico32.zip", tkdev_winico_path)
 if exists(tkdev_twapi_path):
     console("检测到已经安装好twApi！")
 else:
     console("未检测到twApi！")
     console("准备开始安装...")
-    install("https://tkdev-docs.netlify.app/_files/twapi.zip", tkdev_twapi_path)
+    install("https://tkdev-docs-old.netlify.app/_files/twapi.zip", tkdev_twapi_path)
 
 console("安装完成！")
 console("初始化完毕！")
